!     #########
      SUBROUTINE PGD_TEB_PAR (DTCO, DGU, UG, U, USS, BDD, DTT, DTI, TG, &
                              HPROGRAM,OGARDEN,OGREENROOF,HBLD_ATYPE)
!     ##############################################################
!
!!**** *PGD_TEB_PAR* monitor for averaging and interpolations of cover fractions
!!
!!    PURPOSE
!!    -------
!!
!!    METHOD
!!    ------
!!   
!
!!    EXTERNAL
!!    --------
!!
!!    IMPLICIT ARGUMENTS
!!    ------------------
!!
!!    REFERENCE
!!    ---------
!!
!!    AUTHOR
!!    ------
!!
!!    V. Masson        Meteo-France
!!
!!    MODIFICATION
!!    ------------
!!
!!    Original    10/12/97
!!
!!       Modified 08/12/05, P. Le Moigne: user defined fields
!!    G. Pigeon      09/2012: add ROUGH_WALL/ROUGH_ROOF for outdoor convection
!!    V. Masson      08/2013: adds solar panels
!!
!----------------------------------------------------------------------------
!
!*    0.     DECLARATION
!            -----------
!
!
!
USE MODD_DATA_COVER_n, ONLY : DATA_COVER_t
USE MODD_DIAG_SURF_ATM_n, ONLY : DIAG_SURF_ATM_t
USE MODD_SURF_ATM_GRID_n, ONLY : SURF_ATM_GRID_t
USE MODD_SURF_ATM_n, ONLY : SURF_ATM_t
USE MODD_SURF_ATM_SSO_n, ONLY : SURF_ATM_SSO_t
USE MODD_BLD_DESCRIPTION_n, ONLY : BLD_DESC_t
USE MODD_DATA_TEB_n, ONLY : DATA_TEB_t
USE MODD_DATA_ISBA_n, ONLY : DATA_ISBA_t
USE MODD_TEB_GRID_n, ONLY : TEB_GRID_t
!
USE MODD_SURF_PAR,   ONLY : XUNDEF, NUNDEF
!
USE MODI_GET_LUOUT
USE MODI_OPEN_NAMELIST
USE MODI_CLOSE_NAMELIST
USE MODI_INI_VAR_FROM_DATA_0D
USE MODI_INI_VAR_FROM_DATA
USE MODI_TEST_NAM_VAR_SURF
USE MODI_READ_CSVDATA_TEB
USE MODI_BLDCODE
!
USE MODE_POS_SURF
!
!
USE YOMHOOK   ,ONLY : LHOOK,   DR_HOOK
USE PARKIND1  ,ONLY : JPRB
!
USE MODI_ABOR1_SFX
!
IMPLICIT NONE
!
!*    0.1    Declaration of arguments
!            ------------------------
!
!
TYPE(DATA_COVER_t), INTENT(INOUT) :: DTCO
TYPE(DIAG_SURF_ATM_t), INTENT(INOUT) :: DGU
TYPE(SURF_ATM_GRID_t), INTENT(INOUT) :: UG
TYPE(SURF_ATM_t), INTENT(INOUT) :: U
TYPE(SURF_ATM_SSO_t), INTENT(INOUT) :: USS
TYPE(BLD_DESC_t), INTENT(INOUT) :: BDD
TYPE(DATA_TEB_t), INTENT(INOUT) :: DTT
TYPE(DATA_ISBA_t), INTENT(INOUT) :: DTI
TYPE(TEB_GRID_t), INTENT(INOUT) :: TG
!
 CHARACTER(LEN=6),    INTENT(IN)    :: HPROGRAM     ! Type of program
LOGICAL,             INTENT(IN)    :: OGARDEN      ! T if urban green areas
LOGICAL,             INTENT(IN)    :: OGREENROOF   ! T if greenroofs option is activated
 CHARACTER(LEN=3),    INTENT(OUT)   :: HBLD_ATYPE    ! Type of building averaging
!
!
!*    0.2    Declaration of local variables
!            ------------------------------
!
INTEGER               :: ILUOUT    ! output listing logical unit
INTEGER               :: ILUNAM    ! namelist file  logical unit
LOGICAL               :: GFOUND    ! true if namelist is found
INTEGER               :: JJ        ! Loop index
!
REAL, DIMENSION(TG%NDIM) :: ZWORK
REAL                  :: ZUNIF     ! temporary variable
!
!*    0.3    Declaration of namelists
!            ------------------------
!
INTEGER, PARAMETER :: NROOF_MAX  = 9
INTEGER, PARAMETER :: NROAD_MAX  = 9
INTEGER, PARAMETER :: NWALL_MAX  = 9
INTEGER            :: NPAR_ROAD_LAYER ! number of road layers
INTEGER            :: NPAR_ROOF_LAYER ! number of roof layers
INTEGER            :: NPAR_WALL_LAYER ! number of wall layers
!
! Geometric Parameters:
!
INTEGER                                 :: NUNIF_BLDTYPE
CHARACTER(LEN=28)                       :: CFNAM_BLDTYPE
CHARACTER(LEN=6)                        :: CFTYP_BLDTYPE
INTEGER                                 :: NUNIF_IND_BLD_AGE
CHARACTER(LEN=28)                       :: CFNAM_IND_BLD_AGE
CHARACTER(LEN=6)                        :: CFTYP_IND_BLD_AGE
INTEGER                                 :: NUNIF_COL_BLD_AGE
CHARACTER(LEN=28)                       :: CFNAM_COL_BLD_AGE
CHARACTER(LEN=6)                        :: CFTYP_COL_BLD_AGE
CHARACTER(LEN=28)                       :: CCSVFILEARCHI
CHARACTER(LEN=28)                       :: CCSVFILECOMPO
INTEGER                                 :: NUNIF_USETYPE
CHARACTER(LEN=28)                       :: CFNAM_USETYPE
CHARACTER(LEN=6)                        :: CFTYP_USETYPE
INTEGER                                 :: NUNIF_P1TERRITORY
CHARACTER(LEN=28)                       :: CFNAM_P1TERRITORY
CHARACTER(LEN=6)                        :: CFTYP_P1TERRITORY
INTEGER                                 :: NUNIF_PXTERRITORY
CHARACTER(LEN=28)                       :: CFNAM_PXTERRITORY
CHARACTER(LEN=6)                        :: CFTYP_PXTERRITORY
REAL                                    :: XUNIF_FRACIHS
CHARACTER(LEN=28)                       :: CFNAM_FRACIHS
CHARACTER(LEN=6)                        :: CFTYP_FRACIHS
REAL                                    :: XUNIF_FRACCHS
CHARACTER(LEN=28)                       :: CFNAM_FRACCHS
CHARACTER(LEN=6)                        :: CFTYP_FRACCHS
REAL                                    :: XUNIF_FRACCOM
CHARACTER(LEN=28)                       :: CFNAM_FRACCOM
CHARACTER(LEN=6)                        :: CFTYP_FRACCOM
REAL                                    :: XUNIF_FRACTER
CHARACTER(LEN=28)                       :: CFNAM_FRACTER
CHARACTER(LEN=6)                        :: CFTYP_FRACTER
REAL                                    :: XUNIF_FRACIND
CHARACTER(LEN=28)                       :: CFNAM_FRACIND
CHARACTER(LEN=6)                        :: CFTYP_FRACIND
REAL                                    :: XUNIF_FRACPAV
CHARACTER(LEN=28)                       :: CFNAM_FRACPAV
CHARACTER(LEN=6)                        :: CFTYP_FRACPAV
REAL                                    :: XUNIF_FRACMRI
CHARACTER(LEN=28)                       :: CFNAM_FRACMRI
CHARACTER(LEN=6)                        :: CFTYP_FRACMRI
REAL                                    :: XUNIF_FRACHRI
CHARACTER(LEN=28)                       :: CFNAM_FRACHRI
CHARACTER(LEN=6)                        :: CFTYP_FRACHRI
REAL                                    :: XUNIF_FRACATB
CHARACTER(LEN=28)                       :: CFNAM_FRACATB
CHARACTER(LEN=6)                        :: CFTYP_FRACATB
REAL                                    :: XUNIF_FOEQI_MAIS
CHARACTER(LEN=28)                       :: CFNAM_FOEQI_MAIS
CHARACTER(LEN=6)                        :: CFTYP_FOEQI_MAIS
REAL                                    :: XUNIF_FOEQI_APPT
CHARACTER(LEN=28)                       :: CFNAM_FOEQI_APPT
CHARACTER(LEN=6)                        :: CFTYP_FOEQI_APPT
REAL                                    :: XUNIF_FAEQI_MAIS
CHARACTER(LEN=28)                       :: CFNAM_FAEQI_MAIS
CHARACTER(LEN=6)                        :: CFTYP_FAEQI_MAIS
REAL                                    :: XUNIF_FAEQI_APPT
CHARACTER(LEN=28)                       :: CFNAM_FAEQI_APPT
CHARACTER(LEN=6)                        :: CFTYP_FAEQI_APPT
REAL                                    :: XUNIF_CRE_MAIS
CHARACTER(LEN=28)                       :: CFNAM_CRE_MAIS
CHARACTER(LEN=6)                        :: CFTYP_CRE_MAIS
REAL                                    :: XUNIF_CRE_APPT
CHARACTER(LEN=28)                       :: CFNAM_CRE_APPT
CHARACTER(LEN=6)                        :: CFTYP_CRE_APPT
REAL                                    :: XUNIF_EFF_HEAT
CHARACTER(LEN=28)                       :: CFNAM_EFF_HEAT
CHARACTER(LEN=6)                        :: CFTYP_EFF_HEAT
!
CHARACTER(LEN=3)                        :: CBLD_ATYPE         ! type of averaging for buildings
!
REAL                                    :: XUNIF_BLD          ! fraction of buildings            (-)
REAL                                    :: XUNIF_BLD_HEIGHT   ! buildings height 'h'             (m)
REAL                                    :: XUNIF_WALL_O_HOR   ! wall surf. / hor. surf.          (-)
REAL                                    :: XUNIF_Z0_TOWN      ! roughness length for momentum    (m)
REAL                                    :: XUNIF_GARDEN       ! fraction of veg in the streets   (-)
REAL                                    :: XUNIF_GREENROOF    ! fraction of greenroofs on roofs  (-)
REAL                                    :: XUNIF_ROAD_DIR     ! road direction (deg from North, clockwise)
 CHARACTER(LEN=28)                       :: CFNAM_BLD          ! file name for BLD 
 CHARACTER(LEN=28)                       :: CFNAM_BLD_HEIGHT   ! file name for BLD_HEIGHT
 CHARACTER(LEN=28)                       :: CFNAM_WALL_O_HOR   ! file name for WALL_O_HOR
 CHARACTER(LEN=28)                       :: CFNAM_Z0_TOWN      ! file name for Z0_TOWN
 CHARACTER(LEN=28)                       :: CFNAM_GARDEN       ! file name for GARDEN  
 CHARACTER(LEN=28)                       :: CFNAM_GREENROOF    ! file name for GREENROOF
 CHARACTER(LEN=28)                       :: CFNAM_ROAD_DIR     ! file name for ROAD_DIR  
 CHARACTER(LEN=6)                        :: CFTYP_BLD          ! file type for BLD 
 CHARACTER(LEN=6)                        :: CFTYP_BLD_HEIGHT   ! file type for BLD_HEIGHT
 CHARACTER(LEN=6)                        :: CFTYP_WALL_O_HOR   ! file type for WALL_O_HOR
 CHARACTER(LEN=6)                        :: CFTYP_Z0_TOWN      ! file type for Z0_TOWN
 CHARACTER(LEN=6)                        :: CFTYP_GARDEN       ! file type for GARDEN  
 CHARACTER(LEN=6)                        :: CFTYP_GREENROOF    ! file type for GREENROOF
 CHARACTER(LEN=6)                        :: CFTYP_ROAD_DIR     ! file type for ROAD_DIR
!
! Roof parameters
!
REAL                                    :: XUNIF_ALB_ROOF     ! roof albedo                      (-)
REAL                                    :: XUNIF_EMIS_ROOF    ! roof emissivity                  (-)
 CHARACTER(LEN=28)                       :: CFNAM_ALB_ROOF     ! file name for ALB_ROOF
 CHARACTER(LEN=28)                       :: CFNAM_EMIS_ROOF    ! file name for EMIS_ROOF
 CHARACTER(LEN=6)                        :: CFTYP_ALB_ROOF     ! file name for ALB_ROOF   
 CHARACTER(LEN=6)                        :: CFTYP_EMIS_ROOF    ! file name for EMIS_ROOF  
REAL, DIMENSION(NROOF_MAX)              :: XUNIF_HC_ROOF      ! roof layers heat capacity        (J/K/m3)
REAL, DIMENSION(NROOF_MAX)              :: XUNIF_TC_ROOF      ! roof layers thermal conductivity (W/K/m)
REAL, DIMENSION(NROOF_MAX)              :: XUNIF_D_ROOF       ! depth of roof layers             (m)
 CHARACTER(LEN=28), DIMENSION(NROOF_MAX) :: CFNAM_HC_ROOF      ! file name for HC_ROOF   
 CHARACTER(LEN=28), DIMENSION(NROOF_MAX) :: CFNAM_TC_ROOF      ! file name for TC_ROOF
 CHARACTER(LEN=28), DIMENSION(NROOF_MAX) :: CFNAM_D_ROOF       ! file name for D_ROOF
 CHARACTER(LEN=6),  DIMENSION(NROOF_MAX) :: CFTYP_HC_ROOF      ! file type for HC_ROOF   
 CHARACTER(LEN=6),  DIMENSION(NROOF_MAX) :: CFTYP_TC_ROOF      ! file type for TC_ROOF
 CHARACTER(LEN=6),  DIMENSION(NROOF_MAX) :: CFTYP_D_ROOF       ! file type for D_ROOF
REAL                                    :: XUNIF_ROUGH_ROOF  ! roof roughness coef
 CHARACTER(LEN=28)                       :: CFNAM_ROUGH_ROOF  ! file name for ROUGH_ROOF
 CHARACTER(LEN=6)                        :: CFTYP_ROUGH_ROOF  ! file type for ROUGH_ROOF
!
!
! Road parameters
!
REAL                                    :: XUNIF_ALB_ROAD     ! road albedo                      (-)
REAL                                    :: XUNIF_EMIS_ROAD    ! road emissivity                  (-)
 CHARACTER(LEN=28)                       :: CFNAM_ALB_ROAD     ! file name for ALB_ROAD
 CHARACTER(LEN=28)                       :: CFNAM_EMIS_ROAD    ! file name for EMIS_ROAD
 CHARACTER(LEN=6)                        :: CFTYP_ALB_ROAD     ! file type for ALB_ROAD
 CHARACTER(LEN=6)                        :: CFTYP_EMIS_ROAD    ! file type for EMIS_ROAD
REAL, DIMENSION(NROAD_MAX)              :: XUNIF_HC_ROAD      ! road layers heat capacity        (J/K/m3)
REAL, DIMENSION(NROAD_MAX)              :: XUNIF_TC_ROAD      ! road layers thermal conductivity (W/K/m)
REAL, DIMENSION(NROAD_MAX)              :: XUNIF_D_ROAD       ! depth of road layers             (m)
 CHARACTER(LEN=28), DIMENSION(NROAD_MAX) :: CFNAM_HC_ROAD      ! file name for HC_ROAD   
 CHARACTER(LEN=28), DIMENSION(NROAD_MAX) :: CFNAM_TC_ROAD      ! file name for TC_ROAD
 CHARACTER(LEN=28), DIMENSION(NROAD_MAX) :: CFNAM_D_ROAD       ! file name for D_ROAD
 CHARACTER(LEN=6),  DIMENSION(NROAD_MAX) :: CFTYP_HC_ROAD      ! file type for HC_ROAD   
 CHARACTER(LEN=6),  DIMENSION(NROAD_MAX) :: CFTYP_TC_ROAD      ! file type for TC_ROAD
 CHARACTER(LEN=6),  DIMENSION(NROAD_MAX) :: CFTYP_D_ROAD       ! file type for D_ROAD
!
! Wall parameters
!
REAL                                    :: XUNIF_ALB_WALL     ! wall albedo                      (-)
REAL                                    :: XUNIF_EMIS_WALL    ! wall emissivity                  (-)
 CHARACTER(LEN=28)                       :: CFNAM_ALB_WALL     ! file name for ALB_WALL
 CHARACTER(LEN=28)                       :: CFNAM_EMIS_WALL    ! file name for EMIS_WALL
 CHARACTER(LEN=6)                        :: CFTYP_ALB_WALL     ! file type for ALB_WALL
 CHARACTER(LEN=6)                        :: CFTYP_EMIS_WALL    ! file type for EMIS_WALL
REAL, DIMENSION(NWALL_MAX)              :: XUNIF_HC_WALL      ! wall layers heat capacity        (J/K/m3)
REAL, DIMENSION(NWALL_MAX)              :: XUNIF_TC_WALL      ! wall layers thermal conductivity (W/K/m)
REAL, DIMENSION(NWALL_MAX)              :: XUNIF_D_WALL       ! depth of wall layers             (m)
 CHARACTER(LEN=28), DIMENSION(NWALL_MAX) :: CFNAM_HC_WALL      ! file name for HC_WALL   
 CHARACTER(LEN=28), DIMENSION(NWALL_MAX) :: CFNAM_TC_WALL      ! file name for TC_WALL
 CHARACTER(LEN=28), DIMENSION(NWALL_MAX) :: CFNAM_D_WALL       ! file name for D_WALL
 CHARACTER(LEN=6),  DIMENSION(NWALL_MAX) :: CFTYP_HC_WALL      ! file type for HC_WALL   
 CHARACTER(LEN=6),  DIMENSION(NWALL_MAX) :: CFTYP_TC_WALL      ! file type for TC_WALL
 CHARACTER(LEN=6),  DIMENSION(NWALL_MAX) :: CFTYP_D_WALL       ! file type for D_WALL
REAL                                    :: XUNIF_ROUGH_WALL  ! wall roughness coef
 CHARACTER(LEN=28)                       :: CFNAM_ROUGH_WALL  ! file name for ROUGH_WALL
 CHARACTER(LEN=6)                        :: CFTYP_ROUGH_WALL  ! file type for ROUGH_WALL
!
! anthropogenic fluxes
!
REAL                                    :: XUNIF_H_TRAFFIC    ! anthropogenic sensible
!                                                             ! heat fluxes due to traffic       (W/m2)
REAL                                    :: XUNIF_LE_TRAFFIC   ! anthropogenic latent
!                                                             ! heat fluxes due to traffic       (W/m2)
REAL                                    :: XUNIF_H_INDUSTRY   ! anthropogenic sensible                   
!                                                             ! heat fluxes due to factories     (W/m2)
REAL                                    :: XUNIF_LE_INDUSTRY  ! anthropogenic latent
!                                                             ! heat fluxes due to factories     (W/m2)
 CHARACTER(LEN=28)                       :: CFNAM_H_TRAFFIC    ! file name for H_TRAFFIC
 CHARACTER(LEN=28)                       :: CFNAM_LE_TRAFFIC   ! file name for LE_TRAFFIC
 CHARACTER(LEN=28)                       :: CFNAM_H_INDUSTRY   ! file name for H_INDUSTRY
 CHARACTER(LEN=28)                       :: CFNAM_LE_INDUSTRY  ! file name for LE_INDUSTRY
 CHARACTER(LEN=6)                        :: CFTYP_H_TRAFFIC    ! file type for H_TRAFFIC
 CHARACTER(LEN=6)                        :: CFTYP_LE_TRAFFIC   ! file type for LE_TRAFFIC
 CHARACTER(LEN=6)                        :: CFTYP_H_INDUSTRY   ! file type for H_INDUSTRY
 CHARACTER(LEN=6)                        :: CFTYP_LE_INDUSTRY  ! file type for LE_INDUSTRY
!
! Solar panels parameters
!
REAL                                    :: XUNIF_EMIS_PANEL    ! emissivity of solar panel       (-)
REAL                                    :: XUNIF_ALB_PANEL     ! albedo     of solar panel       (-)
REAL                                    :: XUNIF_EFF_PANEL     ! efficiency of solar panel       (-)
REAL                                    :: XUNIF_FRAC_PANEL    ! fraction   of solar panel       (-)
 CHARACTER(LEN=28)                       :: CFNAM_EMIS_PANEL   ! file name for EMIS_PANEL
 CHARACTER(LEN=28)                       :: CFNAM_ALB_PANEL    ! file name for ALB_PANEL
 CHARACTER(LEN=28)                       :: CFNAM_EFF_PANEL    ! file name for EFF_PANEL
 CHARACTER(LEN=28)                       :: CFNAM_FRAC_PANEL   ! file name for FRAC_PANEL
 CHARACTER(LEN=6)                        :: CFTYP_EMIS_PANEL   ! file type for EMIS_PANEL
 CHARACTER(LEN=6)                        :: CFTYP_ALB_PANEL    ! file type for ALB_PANEL
 CHARACTER(LEN=6)                        :: CFTYP_EFF_PANEL    ! file type for EFF_PANEL
 CHARACTER(LEN=6)                        :: CFTYP_FRAC_PANEL   ! file type for FRAC_PANEL

REAL(KIND=JPRB) :: ZHOOK_HANDLE
!

NAMELIST/NAM_DATA_TEB/      NPAR_ROOF_LAYER, NPAR_ROAD_LAYER, NPAR_WALL_LAYER,&
                              CBLD_ATYPE,                                     &
                              NUNIF_BLDTYPE, CFNAM_BLDTYPE, CFTYP_BLDTYPE,    &
                              NUNIF_IND_BLD_AGE, CFNAM_IND_BLD_AGE, CFTYP_IND_BLD_AGE, &
                              NUNIF_COL_BLD_AGE, CFNAM_COL_BLD_AGE, CFTYP_COL_BLD_AGE, &
                              CCSVFILEARCHI,CCSVFILECOMPO,                    &
                              NUNIF_USETYPE, CFNAM_USETYPE, CFTYP_USETYPE,    &
                              NUNIF_P1TERRITORY, CFNAM_P1TERRITORY, CFTYP_P1TERRITORY, &
                              NUNIF_PXTERRITORY, CFNAM_PXTERRITORY, CFTYP_PXTERRITORY, &
                              XUNIF_FRACIHS, CFNAM_FRACIHS, CFTYP_FRACIHS, &
                              XUNIF_FRACCHS, CFNAM_FRACCHS, CFTYP_FRACCHS, &
                              XUNIF_FRACCOM, CFNAM_FRACCOM, CFTYP_FRACCOM, &
                              XUNIF_FRACTER, CFNAM_FRACTER, CFTYP_FRACTER, &
                              XUNIF_FRACIND, CFNAM_FRACIND, CFTYP_FRACIND, &
                              XUNIF_FRACPAV, CFNAM_FRACPAV, CFTYP_FRACPAV, &
                              XUNIF_FRACMRI, CFNAM_FRACMRI, CFTYP_FRACMRI, &
                              XUNIF_FRACHRI, CFNAM_FRACHRI, CFTYP_FRACHRI, &
                              XUNIF_FRACATB, CFNAM_FRACATB, CFTYP_FRACATB, &
                              XUNIF_FOEQI_MAIS , CFNAM_FOEQI_MAIS , CFTYP_FOEQI_MAIS, &
                              XUNIF_FOEQI_APPT , CFNAM_FOEQI_APPT , CFTYP_FOEQI_APPT, &
                              XUNIF_FAEQI_MAIS , CFNAM_FAEQI_MAIS , CFTYP_FAEQI_MAIS, &
                              XUNIF_FAEQI_APPT , CFNAM_FAEQI_APPT , CFTYP_FAEQI_APPT, &
                              XUNIF_CRE_MAIS, CFNAM_CRE_MAIS, CFTYP_CRE_MAIS, &
                              XUNIF_CRE_APPT, CFNAM_CRE_APPT, CFTYP_CRE_APPT, &
                              XUNIF_EFF_HEAT, CFNAM_EFF_HEAT, CFTYP_EFF_HEAT, &
                              XUNIF_ALB_ROOF,                                 &
                              XUNIF_EMIS_ROOF, XUNIF_HC_ROOF, XUNIF_TC_ROOF,  &
                              XUNIF_D_ROOF, XUNIF_ALB_ROAD, XUNIF_EMIS_ROAD,  &
                              XUNIF_HC_ROAD, XUNIF_TC_ROAD, XUNIF_D_ROAD,     &
                              XUNIF_ALB_WALL, XUNIF_EMIS_WALL, XUNIF_HC_WALL, &
                              XUNIF_TC_WALL, XUNIF_D_WALL,                    &
                              XUNIF_Z0_TOWN, XUNIF_BLD, XUNIF_BLD_HEIGHT,     &
                              XUNIF_WALL_O_HOR,                               &
                              XUNIF_H_TRAFFIC, XUNIF_LE_TRAFFIC,              &
                              XUNIF_H_INDUSTRY, XUNIF_LE_INDUSTRY,            &
                              XUNIF_GARDEN, XUNIF_GREENROOF,                  &
                              XUNIF_ROAD_DIR,                                 &
                              CFNAM_ALB_ROOF,                                 &
                              CFNAM_EMIS_ROOF, CFNAM_HC_ROOF, CFNAM_TC_ROOF,  &
                              CFNAM_D_ROOF, CFNAM_ALB_ROAD, CFNAM_EMIS_ROAD,  &
                              CFNAM_HC_ROAD, CFNAM_TC_ROAD, CFNAM_D_ROAD,     &
                              CFNAM_ALB_WALL, CFNAM_EMIS_WALL, CFNAM_HC_WALL, &
                              CFNAM_TC_WALL, CFNAM_D_WALL,                    &
                              CFNAM_Z0_TOWN, CFNAM_BLD, CFNAM_BLD_HEIGHT,     &
                              CFNAM_WALL_O_HOR,                               &
                              CFNAM_H_TRAFFIC, CFNAM_LE_TRAFFIC,              &
                              CFNAM_H_INDUSTRY, CFNAM_LE_INDUSTRY,            &
                              CFNAM_GARDEN, CFNAM_ROAD_DIR, CFNAM_GREENROOF,  &
                              CFTYP_ALB_ROOF,                                 &
                              CFTYP_EMIS_ROOF, CFTYP_HC_ROOF, CFTYP_TC_ROOF,  &
                              CFTYP_D_ROOF, CFTYP_ALB_ROAD, CFTYP_EMIS_ROAD,  &
                              CFTYP_HC_ROAD, CFTYP_TC_ROAD, CFTYP_D_ROAD,     &
                              CFTYP_ALB_WALL, CFTYP_EMIS_WALL, CFTYP_HC_WALL, &
                              CFTYP_TC_WALL, CFTYP_D_WALL,                    &
                              CFTYP_Z0_TOWN, CFTYP_BLD, CFTYP_BLD_HEIGHT,     &
                              CFTYP_WALL_O_HOR,                               &
                              CFTYP_H_TRAFFIC, CFTYP_LE_TRAFFIC,              &
                              CFTYP_H_INDUSTRY, CFTYP_LE_INDUSTRY,            &
                              CFTYP_GARDEN, CFTYP_ROAD_DIR, CFTYP_GREENROOF,  &
                              XUNIF_ROUGH_ROOF, CFNAM_ROUGH_ROOF, CFTYP_ROUGH_ROOF, &
                              XUNIF_ROUGH_WALL, CFNAM_ROUGH_WALL, CFTYP_ROUGH_WALL, &
                              XUNIF_EMIS_PANEL, CFNAM_EMIS_PANEL, CFTYP_EMIS_PANEL, &
                              XUNIF_ALB_PANEL,  CFNAM_ALB_PANEL,  CFTYP_ALB_PANEL,  &
                              XUNIF_EFF_PANEL,  CFNAM_EFF_PANEL,  CFTYP_EFF_PANEL,  &
                              XUNIF_FRAC_PANEL, CFNAM_FRAC_PANEL, CFTYP_FRAC_PANEL

!
!-------------------------------------------------------------------------------
!
!*    1.      Initializations
!             ---------------
!
IF (LHOOK)   CALL DR_HOOK('PGD_TEB_PAR',0,ZHOOK_HANDLE)
NPAR_ROOF_LAYER=0
NPAR_ROAD_LAYER=0
NPAR_WALL_LAYER=0
CBLD_ATYPE ='MAJ'
NUNIF_BLDTYPE      = NUNDEF
NUNIF_IND_BLD_AGE  = NUNDEF
NUNIF_COL_BLD_AGE  = NUNDEF
NUNIF_USETYPE      = NUNDEF
NUNIF_P1TERRITORY  = NUNDEF
NUNIF_PXTERRITORY  = NUNDEF
XUNIF_FRACIHS      = XUNDEF
XUNIF_FRACCHS      = XUNDEF
XUNIF_FRACCOM      = XUNDEF
XUNIF_FRACTER      = XUNDEF
XUNIF_FRACIND      = XUNDEF
XUNIF_FRACPAV      = XUNDEF
XUNIF_FRACMRI      = XUNDEF
XUNIF_FRACHRI      = XUNDEF
XUNIF_FRACATB      = XUNDEF
XUNIF_FOEQI_MAIS      = XUNDEF
XUNIF_FOEQI_APPT      = XUNDEF
XUNIF_FAEQI_MAIS      = XUNDEF
XUNIF_FAEQI_APPT      = XUNDEF
XUNIF_CRE_MAIS     = XUNDEF
XUNIF_CRE_APPT     = XUNDEF
XUNIF_EFF_HEAT     = XUNDEF
XUNIF_BLD          = XUNDEF
XUNIF_BLD_HEIGHT   = XUNDEF
XUNIF_WALL_O_HOR   = XUNDEF
XUNIF_Z0_TOWN      = XUNDEF
XUNIF_ALB_ROOF     = XUNDEF
XUNIF_EMIS_ROOF    = XUNDEF
XUNIF_HC_ROOF      = XUNDEF
XUNIF_TC_ROOF      = XUNDEF
XUNIF_D_ROOF       = XUNDEF
XUNIF_ALB_ROAD     = XUNDEF
XUNIF_EMIS_ROAD    = XUNDEF
XUNIF_HC_ROAD      = XUNDEF
XUNIF_TC_ROAD      = XUNDEF
XUNIF_D_ROAD       = XUNDEF
XUNIF_ALB_WALL     = XUNDEF
XUNIF_EMIS_WALL    = XUNDEF
XUNIF_HC_WALL      = XUNDEF
XUNIF_TC_WALL      = XUNDEF
XUNIF_D_WALL       = XUNDEF
XUNIF_H_TRAFFIC    = XUNDEF
XUNIF_LE_TRAFFIC   = XUNDEF
XUNIF_H_INDUSTRY   = XUNDEF
XUNIF_LE_INDUSTRY  = XUNDEF
XUNIF_GARDEN       = XUNDEF
XUNIF_GREENROOF    = XUNDEF
XUNIF_ROAD_DIR     = XUNDEF
XUNIF_ROUGH_ROOF   = XUNDEF
XUNIF_ROUGH_WALL   = XUNDEF
XUNIF_EMIS_PANEL   = XUNDEF
XUNIF_ALB_PANEL    = XUNDEF
XUNIF_EFF_PANEL    = XUNDEF
XUNIF_FRAC_PANEL   = XUNDEF

CFNAM_BLDTYPE      = '                            '
CFNAM_IND_BLD_AGE  = '                            '
CFNAM_COL_BLD_AGE  = '                            '
CFNAM_USETYPE      = '                            '
CFNAM_P1TERRITORY  = '                            '
CFNAM_PXTERRITORY  = '                            '
CFNAM_FRACIHS      = '                            '
CFNAM_FRACCHS      = '                            '
CFNAM_FRACCOM      = '                            '
CFNAM_FRACTER      = '                            '
CFNAM_FRACIND      = '                            '
CFNAM_FRACPAV      = '                            '
CFNAM_FRACMRI      = '                            '
CFNAM_FRACHRI      = '                            '
CFNAM_FRACATB      = '                            '
CFNAM_FOEQI_MAIS      = '                            '
CFNAM_FOEQI_APPT      = '                            '
CFNAM_FAEQI_MAIS      = '                            '
CFNAM_FAEQI_APPT      = '                            '
CFNAM_CRE_MAIS     = '                            '
CFNAM_CRE_APPT     = '                            '
CFNAM_EFF_HEAT     = '                            '
CCSVFILEARCHI      = '                            '
CCSVFILECOMPO      = '                            '
CFNAM_BLD          = '                            '
CFNAM_BLD_HEIGHT   = '                            '
CFNAM_WALL_O_HOR   = '                            '
CFNAM_Z0_TOWN      = '                            '
CFNAM_ALB_ROOF (:) = '                            '
CFNAM_EMIS_ROOF(:) = '                            '
CFNAM_HC_ROOF  (:) = '                            '
CFNAM_TC_ROOF  (:) = '                            '
CFNAM_D_ROOF   (:) = '                            '
CFNAM_ROUGH_ROOF(:) = '                            '
CFNAM_ROUGH_WALL(:) = '                            '
CFNAM_ALB_ROAD (:) = '                            '
CFNAM_EMIS_ROAD(:) = '                            '
CFNAM_HC_ROAD  (:) = '                            '
CFNAM_TC_ROAD  (:) = '                            '
CFNAM_D_ROAD   (:) = '                            '
CFNAM_ALB_WALL (:) = '                            '
CFNAM_EMIS_WALL(:) = '                            '
CFNAM_HC_WALL  (:) = '                            '
CFNAM_TC_WALL  (:) = '                            '
CFNAM_D_WALL   (:) = '                            '

CFNAM_H_TRAFFIC    = '                            '
CFNAM_LE_TRAFFIC   = '                            '
CFNAM_H_INDUSTRY   = '                            '
CFNAM_LE_INDUSTRY  = '                            '

CFNAM_GARDEN       = '                            '
CFNAM_GREENROOF    = '                            '
CFNAM_ROAD_DIR     = '                            '

CFNAM_EMIS_PANEL   = '                            '
CFNAM_ALB_PANEL    = '                            '
CFNAM_EFF_PANEL    = '                            '
CFNAM_FRAC_PANEL   = '                            '
!
CFTYP_BLDTYPE      = '      '
CFTYP_IND_BLD_AGE  = '      '
CFTYP_COL_BLD_AGE  = '      '
CFTYP_USETYPE      = '      '
CFTYP_P1TERRITORY  = '      '
CFTYP_PXTERRITORY  = '      '
CFTYP_FRACIHS      = '      '
CFTYP_FRACCHS      = '      '
CFTYP_FRACCOM      = '      '
CFTYP_FRACTER      = '      '
CFTYP_FRACIND      = '      '
CFTYP_FRACPAV      = '      '
CFTYP_FRACMRI      = '      '
CFTYP_FRACHRI      = '      '
CFTYP_FRACATB      = '      '
CFTYP_FOEQI_MAIS      = '      '
CFTYP_FOEQI_APPT      = '      '
CFTYP_FAEQI_MAIS      = '      '
CFTYP_FAEQI_APPT      = '      '
CFTYP_CRE_MAIS     = '      '
CFTYP_CRE_APPT     = '      '
CFTYP_EFF_HEAT     = '      '
CFTYP_BLD          = '      '
CFTYP_BLD_HEIGHT   = '      '
CFTYP_WALL_O_HOR   = '      '
CFTYP_Z0_TOWN      = '      '
CFTYP_ALB_ROOF(:)  = '      '
CFTYP_EMIS_ROOF(:) = '      '
CFTYP_HC_ROOF(:)   = '      '
CFTYP_TC_ROOF(:)   = '      '
CFTYP_D_ROOF(:)    = '      '
CFTYP_ROUGH_ROOF(:)    = '      '
CFTYP_ROUGH_WALL(:)    = '      '
CFTYP_ALB_ROAD(:)  = '      '
CFTYP_EMIS_ROAD(:) = '      '
CFTYP_HC_ROAD(:)   = '      '
CFTYP_TC_ROAD(:)   = '      '
CFTYP_D_ROAD(:)    = '      '
CFTYP_ALB_WALL(:)  = '      '
CFTYP_EMIS_WALL(:) = '      '
CFTYP_HC_WALL(:)   = '      '
CFTYP_TC_WALL(:)   = '      '
CFTYP_D_WALL(:)    = '      '
CFTYP_H_TRAFFIC    = '      '
CFTYP_LE_TRAFFIC   = '      '
CFTYP_H_INDUSTRY   = '      '
CFTYP_LE_INDUSTRY  = '      '
CFTYP_GARDEN       = '      '
CFTYP_GREENROOF    = '      '
CFTYP_ROAD_DIR     = '      '
!
CFTYP_EMIS_PANEL   = '      '
CFTYP_ALB_PANEL    = '      '
CFTYP_EFF_PANEL    = '      '
CFTYP_FRAC_PANEL   = '      '
!
!-------------------------------------------------------------------------------
!
!*    2.      Input file for cover types
!             --------------------------
!
 CALL GET_LUOUT(HPROGRAM,ILUOUT)
 CALL OPEN_NAMELIST(HPROGRAM,ILUNAM)
!
 CALL POSNAM(ILUNAM,'NAM_DATA_TEB',GFOUND,ILUOUT)
IF (GFOUND) READ(UNIT=ILUNAM,NML=NAM_DATA_TEB)
!
 CALL CLOSE_NAMELIST(HPROGRAM,ILUNAM)
!
 CALL TEST_NAM_VAR_SURF(ILUOUT,'CBLD_ATYPE',CBLD_ATYPE,'ARI','MAJ')
!
DTT%NPAR_ROOF_LAYER = NPAR_ROOF_LAYER
DTT%NPAR_ROAD_LAYER = NPAR_ROAD_LAYER
DTT%NPAR_WALL_LAYER = NPAR_WALL_LAYER
!
HBLD_ATYPE = CBLD_ATYPE
!-------------------------------------------------------------------------------
!
!* coherence check
!
IF ((     ANY(XUNIF_HC_ROAD/=XUNDEF) .OR. ANY(LEN_TRIM(CFNAM_HC_ROAD)>0) &
     .OR. ANY(XUNIF_TC_ROAD/=XUNDEF) .OR. ANY(LEN_TRIM(CFNAM_TC_ROAD)>0) &
     .OR. ANY(XUNIF_D_ROAD /=XUNDEF) .OR. ANY(LEN_TRIM(CFNAM_D_ROAD )>0) &
    ) .AND. NPAR_ROAD_LAYER<1                                  ) THEN
  CALL ABOR1_SFX('In order to initialize road thermal quantities, please specify NPAR_ROAD_LAYER in namelist NAM_DATA_TEB')
END IF
!
IF ((     ANY(XUNIF_HC_ROOF/=XUNDEF) .OR. ANY(LEN_TRIM(CFNAM_HC_ROOF)>0) &
     .OR. ANY(XUNIF_TC_ROOF/=XUNDEF) .OR. ANY(LEN_TRIM(CFNAM_TC_ROOF)>0) &
     .OR. ANY(XUNIF_D_ROOF /=XUNDEF) .OR. ANY(LEN_TRIM(CFNAM_D_ROOF )>0) &
    ) .AND. NPAR_ROOF_LAYER<1                                  ) THEN
  CALL ABOR1_SFX('In order to initialize ROOF thermal quantities, please specify NPAR_ROOF_LAYER in namelist NAM_DATA_TEB')
END IF
!
IF ((     ANY(XUNIF_HC_WALL/=XUNDEF) .OR. ANY(LEN_TRIM(CFNAM_HC_WALL)>0) &
     .OR. ANY(XUNIF_TC_WALL/=XUNDEF) .OR. ANY(LEN_TRIM(CFNAM_TC_WALL)>0) &
     .OR. ANY(XUNIF_D_WALL /=XUNDEF) .OR. ANY(LEN_TRIM(CFNAM_D_WALL )>0) &
    ) .AND. NPAR_WALL_LAYER<1                                  ) THEN
  CALL ABOR1_SFX('In order to initialize WALL thermal quantities, please specify NPAR_WALL_LAYER in namelist NAM_DATA_TEB')
END IF
!-------------------------------------------------------------------------------
ALLOCATE(DTT%NPAR_BLDTYPE     (TG%NDIM))
ALLOCATE(DTT%NPAR_IND_BLD_AGE (TG%NDIM))
ALLOCATE(DTT%NPAR_COL_BLD_AGE (TG%NDIM))
ALLOCATE(DTT%NPAR_BLDCODE     (TG%NDIM))
ALLOCATE(DTT%NPAR_USETYPE     (TG%NDIM))
ALLOCATE(DTT%NPAR_P1TERRITORY (TG%NDIM))
ALLOCATE(DTT%NPAR_PXTERRITORY (TG%NDIM))
ALLOCATE(DTT%XPAR_FRACIHS     (TG%NDIM))
ALLOCATE(DTT%XPAR_FRACCHS     (TG%NDIM))
ALLOCATE(DTT%XPAR_FRACCOM     (TG%NDIM))
ALLOCATE(DTT%XPAR_FRACTER     (TG%NDIM))
ALLOCATE(DTT%XPAR_FRACIND     (TG%NDIM))
ALLOCATE(DTT%XPAR_FRACPAV     (TG%NDIM))
ALLOCATE(DTT%XPAR_FRACMRI     (TG%NDIM))
ALLOCATE(DTT%XPAR_FRACHRI     (TG%NDIM))
ALLOCATE(DTT%XPAR_FRACATB     (TG%NDIM))
ALLOCATE(DTT%XPAR_FOEQI_MAIS     (TG%NDIM))
ALLOCATE(DTT%XPAR_FOEQI_APPT     (TG%NDIM))
ALLOCATE(DTT%XPAR_FAEQI_MAIS     (TG%NDIM))
ALLOCATE(DTT%XPAR_FAEQI_APPT     (TG%NDIM))
ALLOCATE(DTT%XPAR_CRE_MAIS    (TG%NDIM))
ALLOCATE(DTT%XPAR_CRE_APPT    (TG%NDIM))
ALLOCATE(DTT%XPAR_EFF_HEAT    (TG%NDIM))
ALLOCATE(DTT%XPAR_Z0_TOWN     (TG%NDIM))
ALLOCATE(DTT%XPAR_ALB_ROOF    (TG%NDIM))
ALLOCATE(DTT%XPAR_EMIS_ROOF   (TG%NDIM))
ALLOCATE(DTT%XPAR_ALB_ROAD    (TG%NDIM))
ALLOCATE(DTT%XPAR_EMIS_ROAD   (TG%NDIM))
ALLOCATE(DTT%XPAR_ALB_WALL    (TG%NDIM))
ALLOCATE(DTT%XPAR_EMIS_WALL   (TG%NDIM))
ALLOCATE(DTT%XPAR_BLD         (TG%NDIM))
ALLOCATE(DTT%XPAR_BLD_HEIGHT  (TG%NDIM))
ALLOCATE(DTT%XPAR_WALL_O_HOR  (TG%NDIM))
ALLOCATE(DTT%XPAR_H_TRAFFIC   (TG%NDIM))
ALLOCATE(DTT%XPAR_LE_TRAFFIC  (TG%NDIM))
ALLOCATE(DTT%XPAR_H_INDUSTRY  (TG%NDIM))
ALLOCATE(DTT%XPAR_LE_INDUSTRY (TG%NDIM))
ALLOCATE(DTT%XPAR_GARDEN      (TG%NDIM))
ALLOCATE(DTT%XPAR_GREENROOF   (TG%NDIM))
ALLOCATE(DTT%XPAR_ROAD_DIR    (TG%NDIM))
!
ALLOCATE(DTT%XPAR_HC_ROOF     (TG%NDIM,NPAR_ROOF_LAYER))
ALLOCATE(DTT%XPAR_TC_ROOF     (TG%NDIM,NPAR_ROOF_LAYER))
ALLOCATE(DTT%XPAR_D_ROOF      (TG%NDIM,NPAR_ROOF_LAYER))
ALLOCATE(DTT%XPAR_HC_ROAD     (TG%NDIM,NPAR_ROAD_LAYER))
ALLOCATE(DTT%XPAR_TC_ROAD     (TG%NDIM,NPAR_ROAD_LAYER))
ALLOCATE(DTT%XPAR_D_ROAD      (TG%NDIM,NPAR_ROAD_LAYER))
ALLOCATE(DTT%XPAR_HC_WALL     (TG%NDIM,NPAR_WALL_LAYER))
ALLOCATE(DTT%XPAR_TC_WALL     (TG%NDIM,NPAR_WALL_LAYER))
ALLOCATE(DTT%XPAR_D_WALL      (TG%NDIM,NPAR_WALL_LAYER))
ALLOCATE(DTT%XPAR_ROUGH_ROOF    (TG%NDIM))
ALLOCATE(DTT%XPAR_ROUGH_WALL    (TG%NDIM))
!
ALLOCATE(DTT%XPAR_EMIS_PANEL  (TG%NDIM))
ALLOCATE(DTT%XPAR_ALB_PANEL   (TG%NDIM))
ALLOCATE(DTT%XPAR_EFF_PANEL   (TG%NDIM))
ALLOCATE(DTT%XPAR_FRAC_PANEL  (TG%NDIM))
!
!-------------------------------------------------------------------------------
IF (NROOF_MAX < NPAR_ROOF_LAYER) THEN
  WRITE(ILUOUT,*) '---------------------------------------------'
  WRITE(ILUOUT,*) 'Please update pgd_teb_par.f90 routine :      '
  WRITE(ILUOUT,*) 'The maximum number of ROOF LAYER             '
  WRITE(ILUOUT,*) 'in the declaration of the namelist variables '
  WRITE(ILUOUT,*) 'must be increased to : ', NPAR_ROOF_LAYER
  WRITE(ILUOUT,*) '---------------------------------------------'
  CALL ABOR1_SFX('PGD_TEB_PAR: MAXIMUM NUMBER OF NROOF_LAYER MUST BE INCREASED')
ENDIF
!-------------------------------------------------------------------------------
IF (NROAD_MAX < NPAR_ROAD_LAYER) THEN
  WRITE(ILUOUT,*) '---------------------------------------------'
  WRITE(ILUOUT,*) 'Please update pgd_teb_par.f90 routine :      '
  WRITE(ILUOUT,*) 'The maximum number of ROAD LAYER             '
  WRITE(ILUOUT,*) 'in the declaration of the namelist variables '
  WRITE(ILUOUT,*) 'must be increased to : ', NPAR_ROAD_LAYER
  WRITE(ILUOUT,*) '---------------------------------------------'
  CALL ABOR1_SFX('PGD_TEB_PAR: MAXIMUM NUMBER OF NROAD_LAYER MUST BE INCREASED')
ENDIF
!-------------------------------------------------------------------------------
IF (NWALL_MAX < NPAR_WALL_LAYER) THEN
  WRITE(ILUOUT,*) '---------------------------------------------'
  WRITE(ILUOUT,*) 'Please update pgd_teb_par.f90 routine :      '
  WRITE(ILUOUT,*) 'The maximum number of WALL LAYER             '
  WRITE(ILUOUT,*) 'in the declaration of the namelist variables '
  WRITE(ILUOUT,*) 'must be increased to : ', NPAR_WALL_LAYER
  WRITE(ILUOUT,*) '---------------------------------------------'
  CALL ABOR1_SFX('PGD_TEB_PAR: MAXIMUM NUMBER OF NWALL_LAYER MUST BE INCREASED')
ENDIF

!-------------------------------------------------------------------------------
!
!*    3.      user defined fields are prescribed
!             ----------------------------------
!
!* building's type
ZUNIF = XUNDEF
IF (NUNIF_BLDTYPE/=NUNDEF) ZUNIF=FLOAT(NUNIF_BLDTYPE)
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,'MAJ','BLDTYPE    ','TWN', CFNAM_BLDTYPE,CFTYP_BLDTYPE,ZUNIF,&
        ZWORK(:),DTT%LDATA_BLDTYPE )
IF (.NOT. DTT%LDATA_BLDTYPE) THEN
  DEALLOCATE(DTT%NPAR_BLDTYPE)
ELSE
  DTT%NPAR_BLDTYPE = NINT(ZWORK)
END IF
!
!* building's age (individual housing)
ZUNIF = XUNDEF
IF (NUNIF_IND_BLD_AGE/=NUNDEF) ZUNIF=FLOAT(NUNIF_IND_BLD_AGE)
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,'MAJ','IND_BLD_AGE    ','TWN', CFNAM_IND_BLD_AGE,CFTYP_IND_BLD_AGE,ZUNIF,&
        ZWORK(:),DTT%LDATA_IND_BLD_AGE )
IF (.NOT. DTT%LDATA_IND_BLD_AGE) THEN
  DEALLOCATE(DTT%NPAR_IND_BLD_AGE)
ELSE
  DTT%NPAR_IND_BLD_AGE = NINT(ZWORK)
END IF
!
!* building's age (collective housing)
ZUNIF = XUNDEF
IF (NUNIF_COL_BLD_AGE/=NUNDEF) ZUNIF=FLOAT(NUNIF_COL_BLD_AGE)
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,'MAJ','COL_BLD_AGE    ','TWN', CFNAM_COL_BLD_AGE,CFTYP_COL_BLD_AGE,ZUNIF,&
        ZWORK(:),DTT%LDATA_COL_BLD_AGE )
IF (.NOT. DTT%LDATA_COL_BLD_AGE) THEN
  DEALLOCATE(DTT%NPAR_COL_BLD_AGE)
ELSE
  DTT%NPAR_COL_BLD_AGE = NINT(ZWORK)
END IF
!
!* historical building material territory
ZUNIF = XUNDEF
IF (NUNIF_P1TERRITORY/=NUNDEF) ZUNIF=FLOAT(NUNIF_P1TERRITORY)
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
   HPROGRAM,'MAJ','P1TERRITORY  ','TWN', CFNAM_P1TERRITORY,CFTYP_P1TERRITORY,ZUNIF,&
    ZWORK(:),DTT%LDATA_P1TERRITORY )
IF (.NOT. DTT%LDATA_P1TERRITORY) THEN
   DEALLOCATE(DTT%NPAR_P1TERRITORY)
ELSE
   DTT%NPAR_P1TERRITORY = NINT(ZWORK)
END IF
!
!* recent building material territory
ZUNIF = XUNDEF
IF (NUNIF_PXTERRITORY/=NUNDEF) ZUNIF=FLOAT(NUNIF_PXTERRITORY)
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
   HPROGRAM,'MAJ','PXTERRITORY  ','TWN', CFNAM_PXTERRITORY,CFTYP_PXTERRITORY,ZUNIF,&
    ZWORK(:),DTT%LDATA_PXTERRITORY )
IF (.NOT. DTT%LDATA_PXTERRITORY) THEN
   DEALLOCATE(DTT%NPAR_PXTERRITORY)
ELSE
   DTT%NPAR_PXTERRITORY = NINT(ZWORK)
END IF
!
!* building's use
ZUNIF = XUNDEF
IF (NUNIF_USETYPE/=NUNDEF) ZUNIF=FLOAT(NUNIF_USETYPE)
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,'MAJ','USETYPE    ','TWN', CFNAM_USETYPE,CFTYP_USETYPE,ZUNIF,&
        ZWORK(:),DTT%LDATA_USETYPE )
IF (.NOT. DTT%LDATA_USETYPE) THEN
  DEALLOCATE(DTT%NPAR_USETYPE)
ELSE
  DTT%NPAR_USETYPE = NINT(ZWORK)
END IF
!
IF (DTT%LDATA_BLDTYPE.AND.((.NOT.DTT%LDATA_USETYPE).OR.(.NOT.DTT%LDATA_IND_BLD_AGE).OR.&
       (.NOT.DTT%LDATA_COL_BLD_AGE).OR.((.NOT.DTT%LDATA_P1TERRITORY).OR.(.NOT.DTT%LDATA_PXTERRITORY)))) THEN

  WRITE(ILUOUT,*) '---------------------------------------------'
  WRITE(ILUOUT,*) ' You chose to define building types :        '
  IF (NUNIF_BLDTYPE/=NUNDEF) THEN
    WRITE(ILUOUT,*) ' NUNIF_BLDTYPE=', NUNIF_BLDTYPE
  ELSE
    WRITE(ILUOUT,*) ' CFNAM_BLDTYPE =',CFNAM_BLDTYPE 
    WRITE(ILUOUT,*) ' CFTYP_BLDTYPE =',CFTYP_BLDTYPE 
  END IF
  WRITE(ILUOUT,*) ' But            '
  WRITE(ILUOUT,*) " You did not chose to define building's age, use, or territories"
  WRITE(ILUOUT,*) '- - - - - - - - - - - - - - - - - - - - - - -'
  WRITE(ILUOUT,*) ' Please define the construction date of the buildings. '
  WRITE(ILUOUT,*) ' To do so, use either :'
  WRITE(ILUOUT,*) ' NUNIF_BLD_AGE   (to have a uniform construction date for all buildings'
  WRITE(ILUOUT,*) ' or CFNAM_BLD_AGE and CFTYP_BLD_AGE (to incorporate spatial data ) '
  WRITE(ILUOUT,*) '---------------------------------------------'
  CALL ABOR1_SFX("PGD_TEB_PAR: Building information is missing")
END IF
!
IF (DTT%LDATA_BLDTYPE.OR.DTT%LDATA_IND_BLD_AGE.OR.DTT%LDATA_COL_BLD_AGE.OR. &
    DTT%LDATA_USETYPE.OR.DTT%LDATA_P1TERRITORY.OR.DTT%LDATA_PXTERRITORY) THEN
  !
  ! Read architectural characteristics
  !
  CALL READ_CSVDATA_ARCHI_TEB(BDD, HPROGRAM,CCSVFILEARCHI)
  !
  ! Read behavioural characteristics
  !
  CALL READ_CSVDATA_COMPO_TEB(BDD, HPROGRAM,CCSVFILECOMPO)
  !
ENDIF
!
! Robert: depending on the construction period a switch between the historical
!         and recent construction material territory is made.
!         CAUTION: "1" is hardcoded as the historical construction material class.
!         CAUTION: Hardcoded values for the building types
!
IF (ASSOCIATED(DTT%NPAR_BLDTYPE)) THEN
   DO JJ=1,SIZE(DTT%NPAR_BLDTYPE)
      !
      IF ( (DTT%NPAR_BLDTYPE(JJ).GT.4.5).AND.(DTT%NPAR_BLDTYPE(JJ).LT.8.5) ) THEN
         IF (DTT%NPAR_COL_BLD_AGE(JJ).EQ.1) THEN
            CALL BLDCODE(DTT%NPAR_BLDTYPE(JJ),DTT%NPAR_COL_BLD_AGE(JJ),DTT%NPAR_USETYPE(JJ), &
                         DTT%NPAR_P1TERRITORY(JJ),DTT%NPAR_BLDCODE(JJ))
         ELSE
            CALL BLDCODE(DTT%NPAR_BLDTYPE(JJ),DTT%NPAR_COL_BLD_AGE(JJ),DTT%NPAR_USETYPE(JJ), &
                         DTT%NPAR_PXTERRITORY(JJ),DTT%NPAR_BLDCODE(JJ))
         ENDIF
      ELSE
         IF (DTT%NPAR_IND_BLD_AGE(JJ).EQ.1) THEN
            CALL BLDCODE(DTT%NPAR_BLDTYPE(JJ),DTT%NPAR_IND_BLD_AGE(JJ),DTT%NPAR_USETYPE(JJ), &
                         DTT%NPAR_P1TERRITORY(JJ),DTT%NPAR_BLDCODE(JJ))
         ELSE
            CALL BLDCODE(DTT%NPAR_BLDTYPE(JJ),DTT%NPAR_IND_BLD_AGE(JJ),DTT%NPAR_USETYPE(JJ), &
                         DTT%NPAR_PXTERRITORY(JJ),DTT%NPAR_BLDCODE(JJ))
         ENDIF
      ENDIF
      !
   ENDDO
ENDIF
!
!
!* other building parameters
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,'ARI','BLD        ','TWN', CFNAM_BLD,CFTYP_BLD,XUNIF_BLD,DTT%XPAR_BLD,DTT%LDATA_BLD )
IF (.NOT.DTT%LDATA_BLD) DEALLOCATE(DTT%XPAR_BLD)
!
! Check building fraction
!
IF (MAXVAL(DTT%XPAR_BLD).GT.+1.00001) CALL ABOR1_SFX("Too high building fraction")
IF (MINVAL(DTT%XPAR_BLD).LT.-0.00001) CALL ABOR1_SFX("Too low  building fraction")
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,'ARI','BLD_HEIGHT ','TWN',CFNAM_BLD_HEIGHT,CFTYP_BLD_HEIGHT,XUNIF_BLD_HEIGHT,&
        DTT%XPAR_BLD_HEIGHT,DTT%LDATA_BLD_HEIGHT)
IF (.NOT.DTT%LDATA_BLD_HEIGHT) DEALLOCATE(DTT%XPAR_BLD_HEIGHT)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,'ARI','WALL_O_HOR ','TWN',CFNAM_WALL_O_HOR,CFTYP_WALL_O_HOR,XUNIF_WALL_O_HOR,&
        DTT%XPAR_WALL_O_HOR,DTT%LDATA_WALL_O_HOR)
IF (.NOT.DTT%LDATA_WALL_O_HOR) DEALLOCATE(DTT%XPAR_WALL_O_HOR)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,'CDN','Z0_TOWN    ','TWN',CFNAM_Z0_TOWN,CFTYP_Z0_TOWN,XUNIF_Z0_TOWN,&
        DTT%XPAR_Z0_TOWN,DTT%LDATA_Z0_TOWN)
IF (.NOT.DTT%LDATA_Z0_TOWN) DEALLOCATE(DTT%XPAR_Z0_TOWN)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
   HPROGRAM,'ARI','FRACIHS    ','TWN',CFNAM_FRACIHS,CFTYP_FRACIHS,XUNIF_FRACIHS,DTT%XPAR_FRACIHS,DTT%LDATA_FRACIHS)
IF (.NOT.DTT%LDATA_FRACIHS) DEALLOCATE(DTT%XPAR_FRACIHS)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
   HPROGRAM,'ARI','FRACCHS    ','TWN',CFNAM_FRACCHS,CFTYP_FRACCHS,XUNIF_FRACCHS,DTT%XPAR_FRACCHS,DTT%LDATA_FRACCHS)
IF (.NOT.DTT%LDATA_FRACCHS) DEALLOCATE(DTT%XPAR_FRACCHS)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
   HPROGRAM,'ARI','FRACCOM    ','TWN',CFNAM_FRACCOM,CFTYP_FRACCOM,XUNIF_FRACCOM,DTT%XPAR_FRACCOM,DTT%LDATA_FRACCOM)
IF (.NOT.DTT%LDATA_FRACCOM) DEALLOCATE(DTT%XPAR_FRACCOM)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
   HPROGRAM,'ARI','FRACTER    ','TWN',CFNAM_FRACTER,CFTYP_FRACTER,XUNIF_FRACTER,DTT%XPAR_FRACTER,DTT%LDATA_FRACTER)
IF (.NOT.DTT%LDATA_FRACTER) DEALLOCATE(DTT%XPAR_FRACTER)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
   HPROGRAM,'ARI','FRACIND    ','TWN',CFNAM_FRACIND,CFTYP_FRACIND,XUNIF_FRACIND,DTT%XPAR_FRACIND,DTT%LDATA_FRACIND)
IF (.NOT.DTT%LDATA_FRACIND) DEALLOCATE(DTT%XPAR_FRACIND)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
   HPROGRAM,'ARI','FRACPAV    ','TWN',CFNAM_FRACPAV,CFTYP_FRACPAV,XUNIF_FRACPAV,DTT%XPAR_FRACPAV,DTT%LDATA_FRACPAV)
IF (.NOT.DTT%LDATA_FRACPAV) DEALLOCATE(DTT%XPAR_FRACPAV)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
   HPROGRAM,'ARI','FRACMRI    ','TWN',CFNAM_FRACMRI,CFTYP_FRACMRI,XUNIF_FRACMRI,DTT%XPAR_FRACMRI,DTT%LDATA_FRACMRI)
IF (.NOT.DTT%LDATA_FRACMRI) DEALLOCATE(DTT%XPAR_FRACMRI)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
   HPROGRAM,'ARI','FRACHRI    ','TWN',CFNAM_FRACHRI,CFTYP_FRACHRI,XUNIF_FRACHRI,DTT%XPAR_FRACHRI,DTT%LDATA_FRACHRI)
IF (.NOT.DTT%LDATA_FRACHRI) DEALLOCATE(DTT%XPAR_FRACHRI)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
   HPROGRAM,'ARI','FRACATB    ','TWN',CFNAM_FRACATB,CFTYP_FRACATB,XUNIF_FRACATB,DTT%XPAR_FRACATB,DTT%LDATA_FRACATB)
IF (.NOT.DTT%LDATA_FRACATB) DEALLOCATE(DTT%XPAR_FRACATB)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
   HPROGRAM,'ARI','FOEQI_MAIS    ','TWN',CFNAM_FOEQI_MAIS,CFTYP_FOEQI_MAIS,XUNIF_FOEQI_MAIS, &
   DTT%XPAR_FOEQI_MAIS,DTT%LDATA_FOEQI_MAIS)
IF (.NOT.DTT%LDATA_FOEQI_MAIS) DEALLOCATE(DTT%XPAR_FOEQI_MAIS)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
   HPROGRAM,'ARI','FOEQI_APPT    ','TWN',CFNAM_FOEQI_APPT,CFTYP_FOEQI_APPT,XUNIF_FOEQI_APPT, &
   DTT%XPAR_FOEQI_APPT,DTT%LDATA_FOEQI_APPT)
IF (.NOT.DTT%LDATA_FOEQI_APPT) DEALLOCATE(DTT%XPAR_FOEQI_APPT)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
   HPROGRAM,'ARI','IU_MAIS    ','TWN',CFNAM_FAEQI_MAIS,CFTYP_FAEQI_MAIS,XUNIF_FAEQI_MAIS, &
   DTT%XPAR_FAEQI_MAIS,DTT%LDATA_FAEQI_MAIS)
IF (.NOT.DTT%LDATA_FAEQI_MAIS) DEALLOCATE(DTT%XPAR_FAEQI_MAIS)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
   HPROGRAM,'ARI','IU_APPT    ','TWN',CFNAM_FAEQI_APPT,CFTYP_FAEQI_APPT,XUNIF_FAEQI_APPT, &
   DTT%XPAR_FAEQI_APPT,DTT%LDATA_FAEQI_APPT)
IF (.NOT.DTT%LDATA_FAEQI_APPT) DEALLOCATE(DTT%XPAR_FAEQI_APPT)
! 
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
   HPROGRAM,'ARI','CRE_MAIS    ','TWN',CFNAM_CRE_MAIS,CFTYP_CRE_MAIS,XUNIF_CRE_MAIS, &
     DTT%XPAR_CRE_MAIS,DTT%LDATA_CRE_MAIS)
IF (.NOT.DTT%LDATA_CRE_MAIS) DEALLOCATE(DTT%XPAR_CRE_MAIS)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
   HPROGRAM,'ARI','CRE_APPT    ','TWN',CFNAM_CRE_APPT,CFTYP_CRE_APPT,XUNIF_CRE_APPT, &
     DTT%XPAR_CRE_APPT,DTT%LDATA_CRE_APPT)
IF (.NOT.DTT%LDATA_CRE_APPT) DEALLOCATE(DTT%XPAR_CRE_APPT)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
   HPROGRAM,'ARI','EFF_HEAT    ','TWN',CFNAM_EFF_HEAT,CFTYP_EFF_HEAT,XUNIF_EFF_HEAT, &
     DTT%XPAR_EFF_HEAT,DTT%LDATA_EFF_HEAT)
IF (.NOT.DTT%LDATA_EFF_HEAT) DEALLOCATE(DTT%XPAR_EFF_HEAT)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,CBLD_ATYPE,'ALB_ROOF   ','TWN',CFNAM_ALB_ROOF,CFTYP_ALB_ROOF,XUNIF_ALB_ROOF  ,&
        DTT%XPAR_ALB_ROOF,DTT%LDATA_ALB_ROOF)
IF (.NOT.DTT%LDATA_ALB_ROOF) DEALLOCATE(DTT%XPAR_ALB_ROOF)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,CBLD_ATYPE,'EMIS_ROOF  ','TWN',CFNAM_EMIS_ROOF,CFTYP_EMIS_ROOF,XUNIF_EMIS_ROOF ,&
        DTT%XPAR_EMIS_ROOF,DTT%LDATA_EMIS_ROOF)
IF (.NOT.DTT%LDATA_EMIS_ROOF) DEALLOCATE(DTT%XPAR_EMIS_ROOF)
!
CALL INI_VAR_FROM_DATA(DTCO, DGU, UG, U, USS, DTI, &
                        HPROGRAM,CBLD_ATYPE,'HC_ROOF  ','TWN',CFNAM_HC_ROOF,CFTYP_HC_ROOF, &
        XUNIF_HC_ROOF,DTT%XPAR_HC_ROOF,DTT%LDATA_HC_ROOF ) 
IF (.NOT.DTT%LDATA_HC_ROOF) DEALLOCATE(DTT%XPAR_HC_ROOF)
! 
CALL INI_VAR_FROM_DATA(DTCO, DGU, UG, U, USS, DTI, &
                        HPROGRAM,CBLD_ATYPE,'TC_ROOF  ','TWN',CFNAM_TC_ROOF,CFTYP_TC_ROOF, &
                 XUNIF_TC_ROOF ,DTT%XPAR_TC_ROOF, DTT%LDATA_TC_ROOF ) 
IF (.NOT.DTT%LDATA_TC_ROOF) DEALLOCATE(DTT%XPAR_TC_ROOF)
! 
CALL INI_VAR_FROM_DATA(DTCO, DGU, UG, U, USS, DTI, &
                        HPROGRAM,CBLD_ATYPE,'D_ROOF   ','TWN',CFNAM_D_ROOF,CFTYP_D_ROOF, &
                 XUNIF_D_ROOF  ,DTT%XPAR_D_ROOF , DTT%LDATA_D_ROOF ) 
IF (.NOT.DTT%LDATA_D_ROOF) DEALLOCATE(DTT%XPAR_D_ROOF)
! 
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,'ARI','ALB_ROAD   ','TWN',CFNAM_ALB_ROAD  ,CFTYP_ALB_ROAD  ,XUNIF_ALB_ROAD  ,&
        DTT%XPAR_ALB_ROAD, DTT%LDATA_ALB_ROAD  )
IF (.NOT.DTT%LDATA_ALB_ROAD) DEALLOCATE(DTT%XPAR_ALB_ROAD)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,'ARI','EMIS_ROAD  ','TWN',CFNAM_EMIS_ROAD ,CFTYP_EMIS_ROAD ,XUNIF_EMIS_ROAD ,&
        DTT%XPAR_EMIS_ROAD, DTT%LDATA_EMIS_ROAD )
IF (.NOT.DTT%LDATA_EMIS_ROAD) DEALLOCATE(DTT%XPAR_EMIS_ROAD)
!
CALL INI_VAR_FROM_DATA(DTCO, DGU, UG, U, USS, DTI, &
                        HPROGRAM,CBLD_ATYPE,'HC_ROAD  ','TWN',CFNAM_HC_ROAD ,CFTYP_HC_ROAD , &
                   XUNIF_HC_ROAD ,DTT%XPAR_HC_ROAD, DTT%LDATA_HC_ROAD  )  
IF (.NOT.DTT%LDATA_HC_ROAD) DEALLOCATE(DTT%XPAR_HC_ROAD)
!
CALL INI_VAR_FROM_DATA(DTCO, DGU, UG, U, USS, DTI, &
                        HPROGRAM,CBLD_ATYPE,'TC_ROAD  ','TWN',CFNAM_TC_ROAD ,CFTYP_TC_ROAD , &
                   XUNIF_TC_ROAD ,DTT%XPAR_TC_ROAD, DTT%LDATA_TC_ROAD  )  
IF (.NOT.DTT%LDATA_TC_ROAD) DEALLOCATE(DTT%XPAR_TC_ROAD)
!
CALL INI_VAR_FROM_DATA(DTCO, DGU, UG, U, USS, DTI, &
                        HPROGRAM,'ARI','D_ROAD   ','TWN',CFNAM_D_ROAD  ,CFTYP_D_ROAD  , &
                   XUNIF_D_ROAD  ,DTT%XPAR_D_ROAD , DTT%LDATA_D_ROAD  )
IF (.NOT.DTT%LDATA_D_ROAD) DEALLOCATE(DTT%XPAR_D_ROAD)
!  
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,CBLD_ATYPE,'ALB_WALL   ','TWN',CFNAM_ALB_WALL  ,CFTYP_ALB_WALL  ,XUNIF_ALB_WALL  ,&
        DTT%XPAR_ALB_WALL, DTT%LDATA_ALB_WALL   )
IF (.NOT.DTT%LDATA_ALB_WALL) DEALLOCATE(DTT%XPAR_ALB_WALL)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,CBLD_ATYPE,'EMIS_WALL  ','TWN',CFNAM_EMIS_WALL ,CFTYP_EMIS_WALL ,XUNIF_EMIS_WALL ,&
        DTT%XPAR_EMIS_WALL, DTT%LDATA_EMIS_WALL  )
IF (.NOT.DTT%LDATA_EMIS_WALL) DEALLOCATE(DTT%XPAR_EMIS_WALL)
!
CALL INI_VAR_FROM_DATA(DTCO, DGU, UG, U, USS, DTI, &
                        HPROGRAM,CBLD_ATYPE,'HC_WALL  ','TWN',CFNAM_HC_WALL ,CFTYP_HC_WALL , &
                   XUNIF_HC_WALL ,DTT%XPAR_HC_WALL, DTT%LDATA_HC_WALL  ) 
IF (.NOT.DTT%LDATA_HC_WALL) DEALLOCATE(DTT%XPAR_HC_WALL)
! 
CALL INI_VAR_FROM_DATA(DTCO, DGU, UG, U, USS, DTI, &
                        HPROGRAM,CBLD_ATYPE,'TC_WALL  ','TWN',CFNAM_TC_WALL ,CFTYP_TC_WALL , &
                   XUNIF_TC_WALL ,DTT%XPAR_TC_WALL, DTT%LDATA_TC_WALL  ) 
IF (.NOT.DTT%LDATA_TC_WALL) DEALLOCATE(DTT%XPAR_TC_WALL)
! 
CALL INI_VAR_FROM_DATA(DTCO, DGU, UG, U, USS, DTI, &
                        HPROGRAM,CBLD_ATYPE,'D_WALL   ','TWN',CFNAM_D_WALL  ,CFTYP_D_WALL  , &
                   XUNIF_D_WALL  ,DTT%XPAR_D_WALL , DTT%LDATA_D_WALL  ) 
IF (.NOT.DTT%LDATA_D_WALL) DEALLOCATE(DTT%XPAR_D_WALL)
! 
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,'ARI','H_TRAFFIC  ','TWN',CFNAM_H_TRAFFIC  ,CFTYP_H_TRAFFIC  ,XUNIF_H_TRAFFIC  ,&
        DTT%XPAR_H_TRAFFIC, DTT%LDATA_H_TRAFFIC   )
IF (.NOT.DTT%LDATA_H_TRAFFIC) DEALLOCATE(DTT%XPAR_H_TRAFFIC)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,'ARI','LE_TRAFFIC ','TWN',CFNAM_LE_TRAFFIC ,CFTYP_LE_TRAFFIC ,XUNIF_LE_TRAFFIC ,&
        DTT%XPAR_LE_TRAFFIC, DTT%LDATA_LE_TRAFFIC  )
IF (.NOT.DTT%LDATA_LE_TRAFFIC) DEALLOCATE(DTT%XPAR_LE_TRAFFIC)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,'ARI','H_INDUSTRY ','TWN',CFNAM_H_INDUSTRY ,CFTYP_H_INDUSTRY ,XUNIF_H_INDUSTRY ,&
        DTT%XPAR_H_INDUSTRY, DTT%LDATA_H_INDUSTRY  )
IF (.NOT.DTT%LDATA_H_INDUSTRY) DEALLOCATE(DTT%XPAR_H_INDUSTRY)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,'ARI','LE_INDUSTRY','TWN',CFNAM_LE_INDUSTRY,CFTYP_LE_INDUSTRY,XUNIF_LE_INDUSTRY,&
        DTT%XPAR_LE_INDUSTRY, DTT%LDATA_LE_INDUSTRY )
IF (.NOT.DTT%LDATA_LE_INDUSTRY) DEALLOCATE(DTT%XPAR_LE_INDUSTRY)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,CBLD_ATYPE,'ROUGH_ROOF','TWN',CFNAM_ROUGH_ROOF,CFTYP_ROUGH_ROOF,XUNIF_ROUGH_ROOF ,&
        DTT%XPAR_ROUGH_ROOF,DTT%LDATA_ROUGH_ROOF)
IF (.NOT.DTT%LDATA_ROUGH_ROOF) DEALLOCATE(DTT%XPAR_ROUGH_ROOF)
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,CBLD_ATYPE,'ROUGH_WALL','TWN',CFNAM_ROUGH_WALL,CFTYP_ROUGH_WALL,XUNIF_ROUGH_WALL ,&
        DTT%XPAR_ROUGH_WALL,DTT%LDATA_ROUGH_WALL)
IF (.NOT.DTT%LDATA_ROUGH_WALL) DEALLOCATE(DTT%XPAR_ROUGH_WALL)
!
!-------------------------------------------------------------------------------
!
!* coherence checks
!
 CALL COHERENCE_THERMAL_DATA('ROAD',DTT%LDATA_HC_ROAD,DTT%LDATA_TC_ROAD,DTT%LDATA_D_ROAD)
 CALL COHERENCE_THERMAL_DATA('ROOF',DTT%LDATA_HC_ROOF,DTT%LDATA_TC_ROOF,DTT%LDATA_D_ROOF)
 CALL COHERENCE_THERMAL_DATA('WALL',DTT%LDATA_HC_WALL,DTT%LDATA_TC_WALL,DTT%LDATA_D_WALL)

!-------------------------------------------------------------------------------
!
!* road directions
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,'ARI','ROAD_DIR   ','TWN',CFNAM_ROAD_DIR  ,CFTYP_ROAD_DIR    ,XUNIF_ROAD_DIR   ,&
        DTT%XPAR_ROAD_DIR, DTT%LDATA_ROAD_DIR    )
IF (.NOT.DTT%LDATA_ROAD_DIR) DEALLOCATE(DTT%XPAR_ROAD_DIR)
!
!-------------------------------------------------------------------------------
!
!* solar panels
!
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,'ARI','EMIS_PANEL ','BLD',CFNAM_EMIS_PANEL,CFTYP_EMIS_PANEL,XUNIF_EMIS_PANEL,&
       DTT%XPAR_EMIS_PANEL, DTT%LDATA_EMIS_PANEL    )
IF (.NOT.DTT%LDATA_EMIS_PANEL) DEALLOCATE(DTT%XPAR_EMIS_PANEL)
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,'ARI','ALB_PANEL  ','BLD',CFNAM_ALB_PANEL ,CFTYP_ALB_PANEL ,XUNIF_ALB_PANEL ,&
       DTT%XPAR_ALB_PANEL , DTT%LDATA_ALB_PANEL     )
IF (.NOT.DTT%LDATA_ALB_PANEL ) DEALLOCATE(DTT%XPAR_ALB_PANEL )
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,'ARI','EFF_PANEL  ','BLD',CFNAM_EFF_PANEL ,CFTYP_EFF_PANEL ,XUNIF_EFF_PANEL ,&
       DTT%XPAR_EFF_PANEL , DTT%LDATA_EFF_PANEL     )
IF (.NOT.DTT%LDATA_EFF_PANEL ) DEALLOCATE(DTT%XPAR_EFF_PANEL )
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,'ARI','FRAC_PANEL ','BLD',CFNAM_FRAC_PANEL,CFTYP_FRAC_PANEL,XUNIF_FRAC_PANEL,&
       DTT%XPAR_FRAC_PANEL, DTT%LDATA_FRAC_PANEL    )
IF (.NOT.DTT%LDATA_FRAC_PANEL) DEALLOCATE(DTT%XPAR_FRAC_PANEL)
!
!-------------------------------------------------------------------------------
!
!* greenroof fraction
!
IF (OGREENROOF) THEN
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,CBLD_ATYPE,'GREENROOF','BLD',CFNAM_GREENROOF,CFTYP_GREENROOF,XUNIF_GREENROOF ,&
        DTT%XPAR_GREENROOF,DTT%LDATA_GREENROOF)
  IF (.NOT.DTT%LDATA_GREENROOF) DEALLOCATE(DTT%XPAR_GREENROOF)
ELSE IF ( (XUNIF_GREENROOF/=0. .AND. XUNIF_GREENROOF/=XUNDEF) .OR. LEN_TRIM(CFNAM_GREENROOF)/=0) THEN
  WRITE(ILUOUT,*) '---------------------------------------------'
  WRITE(ILUOUT,*) ' You chose not to include greenroofs in urban areas : LGREENROOF=.FALSE.     '
  WRITE(ILUOUT,*) ' But            '
  IF (XUNIF_GREENROOF/=0. .AND. XUNIF_GREENROOF/=XUNDEF) THEN
    WRITE(ILUOUT,*) ' You also chose a greenroof fraction that is not zero : XUNIF_GREENROOF=',XUNIF_GREENROOF
  ELSE
    WRITE(ILUOUT,*) ' You also chose a greenroof fraction that is not zero : CFNAM_GREENROOF=',CFNAM_GREENROOF
  END IF
  WRITE(ILUOUT,*) '- - - - - - - - - - - - - - - - - - - - - - -'
  WRITE(ILUOUT,*) ' Please choose either:'
  WRITE(ILUOUT,*) ' LGREENROOF=.TRUE. or set GREENROOF fraction to zero (XUNIF_GREENROOF=0.) in namelist PGD_TEB_PAR'
  WRITE(ILUOUT,*) '---------------------------------------------'
  CALL ABOR1_SFX('PGD_TEB_PAR: GREENROOF flag and GREENROOF fraction not coherent')
END IF
!
!-------------------------------------------------------------------------------
!
!* gardens
!
IF (OGARDEN) THEN
CALL INI_VAR_FROM_DATA_0D(DTCO, DGU, UG, U, USS, &
                           HPROGRAM,'ARI','GARDEN     ','TWN',CFNAM_GARDEN    ,CFTYP_GARDEN    ,XUNIF_GARDEN    ,&
        DTT%XPAR_GARDEN, DTT%LDATA_GARDEN    )
  IF (.NOT.DTT%LDATA_GARDEN) DEALLOCATE(DTT%XPAR_GARDEN)
  !
  ! Check garden fraction
  !
  IF (MAXVAL(DTT%XPAR_GARDEN).GT.+1.00001) CALL ABOR1_SFX("Too high garden fraction")
  IF (MINVAL(DTT%XPAR_GARDEN).LT.-0.00001) CALL ABOR1_SFX("Too low  garden fraction")
  !
  ! Robert: check sum of building and garden fraction
  !
  IF (MAXVAL(DTT%XPAR_BLD+DTT%XPAR_GARDEN).GT.+1.00001) CALL ABOR1_SFX("Too high sum of bld and garden fraction")
  !
ELSE IF ( (XUNIF_GARDEN/=0. .AND. XUNIF_GARDEN/=XUNDEF) .OR. LEN_TRIM(CFNAM_GARDEN)/=0) THEN
  WRITE(ILUOUT,*) '---------------------------------------------'
  WRITE(ILUOUT,*) ' You chose not to include gardens in urban areas : LGARDEN=.FALSE.     '
  WRITE(ILUOUT,*) ' But            '
  IF (XUNIF_GARDEN/=0. .AND. XUNIF_GARDEN/=XUNDEF) THEN
    WRITE(ILUOUT,*) ' You also chose a garden fraction that is not zero : XUNIF_GARDEN=',XUNIF_GARDEN
  ELSE
    WRITE(ILUOUT,*) ' You also chose a garden fraction that is not zero : CFNAM_GARDEN=',CFNAM_GARDEN
  END IF
  WRITE(ILUOUT,*) '- - - - - - - - - - - - - - - - - - - - - - -'
  WRITE(ILUOUT,*) ' Please choose either:'
  WRITE(ILUOUT,*) ' LGARDEN=.TRUE. or set GARDEN fraction to zero (XUNIF_GARDEN=0.) in namelist PGD_TEB_PAR'
  WRITE(ILUOUT,*) '- - - - - - - - - - - - - - - - - - - - - - -'
  WRITE(ILUOUT,*) ' Beware that in this case, it may be necessary to change the'
  WRITE(ILUOUT,*) ' road fraction if you want to keep the same canyon aspect ratio'
  WRITE(ILUOUT,*) '---------------------------------------------'
  CALL ABOR1_SFX('PGD_TEB_PAR: GARDEN flag and GARDEN fraction not coherent')
END IF
!
!
!-------------------------------------------------------------------------------
IF (LHOOK)   CALL DR_HOOK('PGD_TEB_PAR',1,ZHOOK_HANDLE)
!-------------------------------------------------------------------------------
CONTAINS
SUBROUTINE COHERENCE_THERMAL_DATA(HTYPE,ODATA_HC,ODATA_TC,ODATA_D)
 CHARACTER(LEN=4), INTENT(IN) :: HTYPE
LOGICAL,          INTENT(IN) :: ODATA_HC
LOGICAL,          INTENT(IN) :: ODATA_TC
LOGICAL,          INTENT(IN) :: ODATA_D
!
IF (ODATA_HC .OR. ODATA_TC .OR. ODATA_D) THEN
  IF (.NOT. (ODATA_HC .AND. ODATA_TC .AND. ODATA_D)) THEN
    WRITE(ILUOUT,*) '*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*'
    WRITE(ILUOUT,*) 'When specifying data for thermal ',TRIM(HTYPE),' characteristics,'
    WRITE(ILUOUT,*) 'All three parameters MUST be defined:'
    WRITE(ILUOUT,*) 'Heat capacity, Thermal conductivity and depths of layers'
    WRITE(ILUOUT,*) ' '
    WRITE(ILUOUT,*) 'In your case :'
    IF (ODATA_HC) THEN
      WRITE(ILUOUT,*) 'Heat capacity is defined'
    ELSE
      WRITE(ILUOUT,*) 'Heat capacity is NOT defined'
    END IF
    IF (ODATA_TC) THEN
      WRITE(ILUOUT,*) 'Thermal conductivity is defined'
    ELSE
      WRITE(ILUOUT,*) 'Thermal conductivity is NOT defined'
    END IF
    IF (ODATA_D) THEN
      WRITE(ILUOUT,*) 'Depths of layers are defined'
    ELSE
      WRITE(ILUOUT,*) 'Depths of layers are NOT defined'
    END IF
    WRITE(ILUOUT,*) '*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*'
    CALL ABOR1_SFX('Heat capacity, Thermal conductivity and depths of layers MUST all be defined for '//HTYPE)
  END IF
END IF
END SUBROUTINE COHERENCE_THERMAL_DATA
!-------------------------------------------------------------------------------
!
END SUBROUTINE PGD_TEB_PAR
